/**
 * @file
 * Behaviours for the Fundraise Up JS module.
 */
(function ($, Drupal, once) {
  // Check that FundraiseUp is available globally on the window.
  if (!window.FundraiseUp) {
    console.error('FundraiseUp JS is not available for the Fundraise Up JS module.');
    return;
  }
  
  Drupal.behaviors.fundraiseUpJS = {
    attach: function (context) {
      /**
       * Open checkout method.
       *
       * Find elements within the context that have a
       * `data-fundraiseup-js-open-checkout` attribute and use them to trigger
       * the FundraiseUp openCheckout method.
       *
       * The value of the data attribute must be the campaign ID.
       *
       *  See https://fundraiseup.com/docs/javascript-api/#open-checkout-method
       */
      $(
        once('data-fundraiseup-js-open-checkout', '[data-fundraiseup-js-open-checkout]', context),
      ).on('click', function (event) {
        event.preventDefault();
        const campaignId = $(this).data('fundraiseup-js-open-checkout');
        if (!campaignId) {
          console.error('No campaign ID found in data attribute.');
          return;
        }
        // Open the FundraiseUp checkout.
        window.FundraiseUp.openCheckout(campaignId);
      });
    }
  };
})(jQuery, Drupal, once);
