<?php

declare(strict_types=1);

namespace Drupal\fundraiseup_js\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Fundraise Up JS settings for this site.
 */
final class ConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'fundraiseup_js_config';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['fundraiseup_js.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('fundraiseup_js.settings');

    $form['site_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Site ID'),
      '#description' => $this->t('The ID provided by Fundraise Up for use in the JS code. E.g. "ABCDEFGH".'),
      '#default_value' => $this->config('fundraiseup_js.settings')->get('site_id'),
      '#required' => TRUE,
    ];

    $form['live_mode'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Live Mode'),
      '#description' => $this->t('When enabled, donations will be processed in live mode. Disable for testing.'),
      '#default_value' => $config->get('live_mode') ?? TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    $site_id = $form_state->getValue('site_id');
    if (!empty($site_id) && !preg_match('/^[a-zA-Z_0-9]+$/', $site_id)) {
      $form_state->setErrorByName('site_id', $this->t('Site ID must be an alphanumeric string.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('fundraiseup_js.settings')
      ->set('site_id', $form_state->getValue('site_id'))
      ->set('live_mode', $form_state->getValue('live_mode'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
